@@ -23,7 +23,10 @@
     tabcoiner <- data.frame(tabcoiner)
     names(tabcoiner) <- names(dudiX$tab)
     row.names(tabcoiner) <- names(dudiY$tab)
-
+    if (nf > dudiX$rank) 
+        nf <- dudiX$rank
+    if (nf > dudiY$rank) 
+        nf <- dudiY$rank
     if ((lig1<col1) & (lig1<col2)) {
         tol <- 1e-07
         w1 <- t(dudiX$tab)*dudiX$cw
@@ -186,7 +189,7 @@
     cat("\n$rank (rank)     :", x$rank)
     cat("\n$nf (axis saved) :", x$nf)
     cat("\n$RV (RV coeff)   :", x$RV)
-    cat("\n\neigen values: ")
+    cat("\n\neigenvalues: ")
     l0 <- length(x$eig)
     cat(signif(x$eig, 4)[1:(min(5, l0))])
     if (l0 > 5) 
@@ -194,28 +197,30 @@
     else cat("\n\n")
     sumry <- array("", c(3, 4), list(1:3, c("vector", "length", 
         "mode", "content")))
-    sumry[1, ] <- c("$eig", length(x$eig), mode(x$eig), "eigen values")
-    sumry[2, ] <- c("$lw", length(x$lw), mode(x$lw), "row weigths (crossed array)")
-    sumry[3, ] <- c("$cw", length(x$cw), mode(x$cw), "col weigths (crossed array)")
+    sumry[1, ] <- c("$eig", length(x$eig), mode(x$eig), "Eigenvalues")
+    sumry[2, ] <- c("$lw", length(x$lw), mode(x$lw), paste("Row weigths (for", x$call[[3]], "cols)"))
+    sumry[3, ] <- c("$cw", length(x$cw), mode(x$cw), paste("Col weigths (for", x$call[[2]], "cols)"))
     
     print(sumry, quote = FALSE)
     cat("\n")
     sumry <- array("", c(11, 4), list(1:11, c("data.frame", "nrow", 
         "ncol", "content")))
-    sumry[1, ] <- c("$tab", nrow(x$tab), ncol(x$tab), "crossed array (CA)")
-    sumry[2, ] <- c("$li", nrow(x$li), ncol(x$li), "Y col = CA row: coordinates")
-    sumry[3, ] <- c("$l1", nrow(x$l1), ncol(x$l1), "Y col = CA row: normed scores")
-    sumry[4, ] <- c("$co", nrow(x$co), ncol(x$co), "X col = CA column: coordinates")
-    sumry[5, ] <- c("$c1", nrow(x$c1), ncol(x$c1), "X col = CA column: normed scores")
-    sumry[6, ] <- c("$lX", nrow(x$lX), ncol(x$lX), "row coordinates (X)")
-    sumry[7, ] <- c("$mX", nrow(x$mX), ncol(x$mX), "normed row scores (X)")
-    sumry[8, ] <- c("$lY", nrow(x$lY), ncol(x$lY), "row coordinates (Y)")
-    sumry[9, ] <- c("$mY", nrow(x$mY), ncol(x$mY), "normed row scores (Y)")
-    sumry[10, ] <- c("$aX", nrow(x$aX), ncol(x$aX), "axis onto co-inertia axis (X)")
-    sumry[11, ] <- c("$aY", nrow(x$aY), ncol(x$aY), "axis onto co-inertia axis (Y)")
+    sumry[1, ] <- c("$tab", nrow(x$tab), ncol(x$tab), paste("Crossed Table (CT): cols(", x$call[[3]], ") x cols(", x$call[[2]], ")", sep=""))
+    sumry[2, ] <- c("$li", nrow(x$li), ncol(x$li), paste("CT row scores (cols of ", x$call[[3]], ")", sep=""))
+    sumry[3, ] <- c("$l1", nrow(x$l1), ncol(x$l1), paste("Principal components (loadings for ", x$call[[3]], " cols)", sep=""))
+    sumry[4, ] <- c("$co", nrow(x$co), ncol(x$co), paste("CT col scores (cols of ", x$call[[2]], ")", sep=""))
+    sumry[5, ] <- c("$c1", nrow(x$c1), ncol(x$c1), paste("Principal axes (cols of ", x$call[[2]], ")", sep=""))
+    sumry[6, ] <- c("$lX", nrow(x$lX), ncol(x$lX), paste("Row scores (rows of ", x$call[[2]], ")", sep=""))
+    sumry[7, ] <- c("$mX", nrow(x$mX), ncol(x$mX), paste("Normed row scores (rows of ", x$call[[2]], ")", sep=""))
+    sumry[8, ] <- c("$lY", nrow(x$lY), ncol(x$lY), paste("Row scores (rows of ", x$call[[3]], ")", sep=""))
+    sumry[9, ] <- c("$mY", nrow(x$mY), ncol(x$mY), paste("Normed row scores (rows of ", x$call[[3]], ")", sep=""))
+    sumry[10, ] <- c("$aX", nrow(x$aX), ncol(x$aX), paste("Corr ", x$call[[2]], " axes / coinertia axes", sep=""))
+    sumry[11, ] <- c("$aY", nrow(x$aY), ncol(x$aY), paste("Corr ", x$call[[3]], " axes / coinertia axes", sep=""))
     
     print(sumry, quote = FALSE)
     cat("\n")
+    cat(paste("CT rows = cols of ", x$call[[3]], " (", nrow(x$li), ") / CT cols = cols of ", x$call[[2]], " (", nrow(x$co),")", sep=""))
+    cat("\n")
 }
 
 "summary.coinertia" <- function (object, ...) {
