@@ -40,13 +40,13 @@ orthobasis.mat <- function(mat, cnw=TRUE) {
     }
     mat <- mat/sum(mat)
     wt <- rep ((1/nlig),nlig) 
-    # calculs extensibles  une pondration quelconque
+    # calculs extensibles à une pondération quelconque
     wt <- wt/sum(wt)
-    # si mat wt est la pondration marginale associe  mat 
+    # si mat wt est la pondération marginale associée à mat 
     # tot = sum(mat)
     # mat = mat-matrix(wt,nlig,nlig,byrow=TRUE)*wt*tot
     # encore plus particulier mat = mat-1/nlig/nlig
-    # en gnral les prcdents sont des cas particuliers    
+    # en général les précédents sont des cas particuliers    
     U <- matrix(1,nlig,nlig)
     U  <- diag(1,nlig)-U*wt
     mat <- U%*%mat%*%t(U)
@@ -60,16 +60,16 @@ orthobasis.mat <- function(mat, cnw=TRUE) {
     if (length(w0)==0) stop ("abnormal output : no null eigenvalue")
     else if (length(w0)==1) w0 <- (1:nlig)[-w0]
     else if (length(w0)>1) {
-        # on ajoute le vecteur driv de 1n 
+        # on ajoute le vecteur dérivé de 1n 
         w <- cbind(wt,eig$vectors[,w0])
         # on orthonormalise l'ensemble
         w <- qr.Q(qr(w))
-        # on met les valeurs propres  0
+        # on met les valeurs propres à 0
         eig$values[w0] <- 0
-        # on remplace les vecteurs du noyau par une base orthonorme contenant 
-        # en premire position le parasite
+        # on remplace les vecteurs du noyau par une base orthonormée contenant 
+        # en première position le parasite
         eig$vectors[,w0] <- w[,-ncol(w)]
-        # on enlve la position du parasite
+        # on enlève la position du parasite
         w0 <- (1:nlig)[-w0[1]]
     }
     mat <- eig$vectors[,w0]/wt
@@ -84,13 +84,13 @@ orthobasis.mat <- function(mat, cnw=TRUE) {
 }
 
 "orthobasis.haar" <- function(n) {
-# on dfinit deux fonctions :
+# on définit deux fonctions :
     appel = match.call()
     a <- log(n)/log(2)
     b <- floor(a)
     if ((a-b)^2>1e-10) stop ("Haar is not a power of 2")
-# la premire est crite par Daniel et elle donne la dmonstration (par analogie avec la fonction qui construit la base Bscores)
-# que la base Bscores est exactement la base de Haar quand on prend une phylognie rgulire rsolue.
+# la première est écrite par Daniel et elle donne la démonstration (par analogie avec la fonction qui construit la base Bscores)
+# que la base Bscores est exactement la base de Haar quand on prend une phylogénie régulière résolue.
 "haar.basis.1" <- function (n) {
     pari <- matrix(c(1,n),1)
     "div2" <- function (mat) {
@@ -123,14 +123,14 @@ orthobasis.mat <- function(mat, cnw=TRUE) {
 return(res)
 }
 
-# la seconde exploite les potentialits de la librairie waveslim, en remarquant qu'il existe un lien troit entre la dfinition des filtres et la dfinition
-# des bases. Cette stratgie permettra  l'avenir de dfinir les bases associes  d'autres famille de fonctions.
+# la seconde exploite les potentialités de la librairie waveslim, en remarquant qu'il existe un lien étroit entre la définition des filtres et la définition
+# des bases. Cette stratégie permettra à l'avenir de définir les bases associées à d'autres famille de fonctions.
 "haar.basis.2" <-  function (n) {
     if (!require(waveslim)) stop ("Please install waveslim")
     J <- a    #nombre de niveau
     res <- matrix(0, nrow = n,ncol = n-1)
     filter.seq <- "H" #filtre correspondant au niveau 1
-    h <- waveslim::wavelet.filter(wf.name = "haar", filter.seq = filter.seq)   #paramtre du filtre au niveau 1
+    h <- waveslim::wavelet.filter(wf.name = "haar", filter.seq = filter.seq)   #paramètre du filtre au niveau 1
     k <- 0
         for(i in 1:J){
         z <- rep(h,2**(J-i))
@@ -148,7 +148,7 @@ return(res)
 return(res)
 }
     
-# suivant que n est grand (n > 257) ou non, on choisit l'une des deux stratgies :
+# suivant que n est grand (n > 257) ou non, on choisit l'une des deux stratégies :
     if (n < 257)
         res <- haar.basis.1(n)
         else
@@ -186,10 +186,10 @@ return(res)
     attr(res,"call") <- appel
     attr(res,"class") <- c("orthobasis","data.frame")
     
-    # vrification locale. Ce paragraphe vrifie que les vecteurs et les valeurs
-    # propose par Cornillon p. 12 sont bien les vecteurs propres de l'oprateur de voisinage
-    # range dans la solution analytique par variance locale croissante
-    # l'article de Mot est erron et a donn le graphe circulaire pour le graphe linaire
+    # vérification locale. Ce paragraphe vérifie que les vecteurs et les valeurs
+    # proposée par Cornillon p. 12 sont bien les vecteurs propres de l'opérateur de voisinage
+    # rangée dans la solution analytique par variance locale croissante
+    # l'article de Méot est erroné et a donné le graphe circulaire pour le graphe linéaire
     # d0=neig2mat(neig(n.lin=n))
     # d0 = d0/n
     # d1=apply(d0,1,sum)
@@ -206,7 +206,7 @@ return(res)
     # abline(lm(attr(res,"values")~lambda))
     # print(coefficients(lm(attr(res,"values")~lambda)))
     
-    # vrification que les valeurs drives des valeurs propres sont exactement des indices de Moran
+    # vérification que les valeurs dérivées des valeurs propres sont exactement des indices de Moran
     # d = neig2mat(neig(n.lin=n))
     # d = d/sum(d) # Moran type W
     # moran <- unlist(lapply(res,function(x) sum(t(d*x)*x)))
@@ -261,7 +261,7 @@ return(res)
     attr(res,"weights") <- rep(1/n,n)
     attr(res,"call") <- appel
     attr(res,"class") <- c("orthobasis","data.frame")        
-    # vrification qu'on a exactement des indices de Moran  partie des valeurs propres
+    # vérification qu'on a exactement des indices de Moran à partie des valeurs propres
     # d = neig2mat(neig(n.cir=n))
     # d = d/sum(d) # Moran type W
     # moran <- unlist(lapply(res,function(x) sum(t(d*x)*x)))
@@ -321,17 +321,17 @@ return(res)
     if (length(w0)==0) stop ("abnormal output : no null eigenvalue")
     else if (length(w0)==1) w0 <- (1:n)[-w0]
     else if (length(w0)>1) {
-        # on ajoute le vecteur driv de 1n 
+        # on ajoute le vecteur dérivé de 1n 
         wt <- rep(1,n)
         w <- cbind(wt,eig$vectors[,w0])
         # on orthonormalise l'ensemble
         w <- qr.Q(qr(w))
-        # on met les valeurs propres  0
+        # on met les valeurs propres à 0
         eig$values[w0] <- 0
-        # on remplace les vecteurs du noyau par une base orthonorme contenant 
-        # en premire position le parasite
+        # on remplace les vecteurs du noyau par une base orthonormée contenant 
+        # en première position le parasite
         eig$vectors[,w0] <- w[,-ncol(w)]
-        # on enlve la position du parasite
+        # on enlève la position du parasite
         w0 <- (1:n)[-w0[1]]
     }
     w0 <- rev(w0)
